/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 *
 */

import * as t from '@babel/types';
import type { NodePath } from '@babel/traverse';
import StateManager from '../utils/state-manager';
/**
 * This function looks for `stylex.defineConsts` calls and transforms them.
 *
 * 1. It finds the first argument to `stylex.defineConsts` and validates it.
 * 2. It evaluates the constants object to get a JS object.
 * 3. It uses `styleXDefineConsts` to transform the object into a structured format.
 * 4. It converts the resulting object back into an AST and replaces the function call with it.
 * 5. The transformed constants are stored in metadata and used during rule processing.
 * 6. During CSS rule generation, any references to `var(--keyhash)` (or `var(--keyhash, fallback)`)
 *    are replaced with their corresponding `constVal` from `defineConsts`.
 * 7. Unlike `stylex.defineVars`, `defineConsts` does not generate runtime CSS variables but instead
 *    directly inlines the resolved values into the final CSS output.
 */
declare function transformStyleXDefineConsts(
  callExpressionPath: NodePath<t.CallExpression>,
  state: StateManager,
): void;
export default transformStyleXDefineConsts;
